==> huaweicloudsdkdcs-3.1.66-py2.py3-none-any.whl: huaweicloudsdkdcs/v2/model/batch_delete_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchDeleteBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'instances': 'list[str]'
    }

    attribute_map = {
        'instances': 'instances'
    }

    def __init__(self, instances=None):
        """BatchDeleteBody

        The model defined in huaweicloud sdk

        :param instances: 实例的ID列表。  仅当URI中参数all_failure值为“false”或者其他值时，才需要配置该参数。 
        :type instances: list[str]
        """
        
        

        self._instances = None
        self.discriminator = None

        if instances is not None:
            self.instances = instances

    @property
    def instances(self):
        """Gets the instances of this BatchDeleteBody.

        实例的ID列表。  仅当URI中参数all_failure值为“false”或者其他值时，才需要配置该参数。 

        :return: The instances of this BatchDeleteBody.
        :rtype: list[str]
        """
        return self._instances

    @instances.setter
    def instances(self, instances):
        """Sets the instances of this BatchDeleteBody.

        实例的ID列表。  仅当URI中参数all_failure值为“false”或者其他值时，才需要配置该参数。 

        :param instances: The instances of this BatchDeleteBody.
        :type instances: list[str]
        """
        self._instances = instances

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchDeleteBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkdcs-3.1.145-py2.py3-none-any.whl: huaweicloudsdkdcs/v2/model/batch_delete_body.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class BatchDeleteBody:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'instances': 'list[str]'
    }

    attribute_map = {
        'instances': 'instances'
    }

    def __init__(self, instances=None):
        r"""BatchDeleteBody

        The model defined in huaweicloud sdk

        :param instances: 实例的ID列表。  仅当URI中参数all_failure值为“false”或者其他值时，才需要配置该参数。 
        :type instances: list[str]
        """
        
        

        self._instances = None
        self.discriminator = None

        if instances is not None:
            self.instances = instances

    @property
    def instances(self):
        r"""Gets the instances of this BatchDeleteBody.

        实例的ID列表。  仅当URI中参数all_failure值为“false”或者其他值时，才需要配置该参数。 

        :return: The instances of this BatchDeleteBody.
        :rtype: list[str]
        """
        return self._instances

    @instances.setter
    def instances(self, instances):
        r"""Sets the instances of this BatchDeleteBody.

        实例的ID列表。  仅当URI中参数all_failure值为“false”或者其他值时，才需要配置该参数。 

        :param instances: The instances of this BatchDeleteBody.
        :type instances: list[str]
        """
        self._instances = instances

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, BatchDeleteBody):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
